rm(list=ls())
library(stargazer)
library(gplots)
library(interactionTest)
library(car)
library(lme4)
library(doBy)
library(foreign)

# location of the deidentified data
prefix <- "E:\\Dropbox\\jesarey_documents\\Gender Corruption Experiment\\experimental-results"

# set working directory
setwd(prefix)

# load data
dat.full <- read.dta("deidentified-appropriation-data.dta")

# drop the first (weird) session
dat <- subset(dat.full, subset=SessionID!="180410_1648")

# create "female" variable; drop "other"
summary(dat$gender)
dat$female <- NA
dat$female[dat$gender=="Female"] <- 1
dat$female[dat$gender=="Male"] <- 0
dat$female[dat$gender=="Other"] <- NA

# convert variables to useful forms
dat$risk.f <- as.factor(dat$risk)
levels(dat$risk.f) <- c("no punishment", "punishment")
table(dat$risk, dat$risk.f) # sanity check

dat$female.f <- as.factor(dat$female)
levels(dat$female.f) <- c("male", "female")
table(dat$female, dat$female.f) # sanity check

dat$riskXfemale <- (as.numeric(dat$risk.f)-1) * (as.numeric(dat$female.f)-1)
table(dat$riskXfemale, dat$female) # sanity check
table(dat$riskXfemale, dat$risk.f) # sanity check

dat$leader.n <- as.numeric(dat$leader)-1
dat$leader.n[dat$leader == ""] <- NA
table(dat$leader.n, dat$leader) # sanity check

dat$Period.f <- as.factor(dat$Period)
table(dat$Period.f, dat$Period) # sanity check

dat$riskgeneral.n <- as.numeric(dat$riskgeneral)
dat$riskgeneral.n[dat$riskgeneral==""] <- NA
dat$riskgeneral.n[dat$riskgeneral=="  2"] <- 0
dat$riskgeneral.n <- dat$riskgeneral.n + 2
table(dat$riskgeneral.n, dat$riskgeneral) # sanity check

# recode risk acceptance to risk aversion
dat$riskgeneral.n.o <- dat$riskgeneral.n
dat$riskgeneral.n <- 11 - dat$riskgeneral.n.o
table(dat$riskgeneral.n, dat$riskgeneral) # sanity check

# recode corruption tolerances to corruption aversions
dat$cheatbribe.n <- 11-as.numeric(dat$cheatbribe)
table(dat$cheatbribe, dat$cheatbribe.n) # sanity check

dat$cheattax.t <- dat$cheattax
dat$cheattax.t[dat$cheattax == ""] <- NA
dat$cheattax.n <- as.numeric(dat$cheattax.t)
dat$cheattax.n[dat$cheattax == unique(dat$cheattax)[9]] <- 9
dat$cheattax.n <- 11-dat$cheattax.n
table(dat$cheattax, dat$cheattax.n) # sanity check

dat$cheattrans.n <- NA
dat$cheattrans.n[dat$cheattrans == "  1"] <- 1
dat$cheattrans.n[dat$cheattrans == "  2"] <- 2
dat$cheattrans.n[dat$cheattrans == "  3"] <- 3
dat$cheattrans.n[dat$cheattrans == "  4"] <- 4
dat$cheattrans.n[dat$cheattrans == "  5"] <- 5
dat$cheattrans.n[dat$cheattrans == "  6"] <- 6
dat$cheattrans.n[dat$cheattrans == "  7"] <- 7
dat$cheattrans.n[dat$cheattrans == "  8"] <- 8
dat$cheattrans.n[dat$cheattrans == "  9"] <- 9
dat$cheattrans.n[dat$cheattrans == "  10"] <- 10
dat$cheattrans.n <- 11 - dat$cheattrans.n
table(dat$cheattrans.n, dat$cheattrans)

dat$cheatbenefit.n <- NA
dat$cheatbenefit.n[dat$cheatbenefit == "  1"] <- 1
dat$cheatbenefit.n[dat$cheatbenefit == "  2"] <- 2
dat$cheatbenefit.n[dat$cheatbenefit == "  3"] <- 3
dat$cheatbenefit.n[dat$cheatbenefit == "  4"] <- 4
dat$cheatbenefit.n[dat$cheatbenefit == "  5"] <- 5
dat$cheatbenefit.n[dat$cheatbenefit == "  6"] <- 6
dat$cheatbenefit.n[dat$cheatbenefit == "  7"] <- 7
dat$cheatbenefit.n[dat$cheatbenefit == "  8"] <- 8
dat$cheatbenefit.n[dat$cheatbenefit == "  9"] <- 9
dat$cheatbenefit.n[dat$cheatbenefit == "  10"] <- 10
dat$cheatbenefit.n <- 11-dat$cheatbenefit.n
table(dat$cheatbenefit.n, dat$cheatbenefit)

# create cheatindex
dat$cheatindex <- dat$cheatbribe.n + dat$cheattax.n + dat$cheattrans.n + dat$cheatbenefit.n - 4
summary(dat$cheatindex)
hist(dat$cheatindex)

dat$SessionID.f <- as.factor(dat$SessionID)
table(dat$SessionID.f, dat$SessionID) # sanity check
dat$SessionID.n <- as.numeric(dat$SessionID)-1
table(dat$SessionID.f, dat$SessionID.n) # sanity check

dat$riskgeneralXrisk <- (as.numeric(dat$risk.f)-1) * (dat$riskgeneral.n)
table(dat$riskgeneralXrisk, dat$risk.f) # sanity check
table(dat$riskgeneralXrisk, dat$riskgeneral.n) # sanity check

# collapse data set via averages
dat$SesSub <- as.numeric(dat$SessionID)*1000 + as.numeric(dat$Subject)
length(unique(dat$SesSub))
dat.collapse <- summaryBy(taken + female + risk.f + riskgeneral.n + cheatbenefit.n + cheattrans.n + cheattax.n + cheatbribe.n + cheatindex + leader.n + SessionID.f~ SesSub, data=dat, keep.names=T)

dat.collapse$riskXfemale <- (dat.collapse$risk.f-1)*dat.collapse$female
dat.collapse$risk.temp <- dat.collapse$risk.f
dat.collapse$risk.f <- factor(dat.collapse$risk.temp, levels=c(1,2), labels=c("no punishment", "punishment"))
dat.collapse$female.f <- factor(dat.collapse$female, levels=c(0,1), labels=c("male", "female"))
table(dat.collapse$female, dat.collapse$female.f) # sanity check
table(dat.collapse$risk.temp, dat.collapse$risk.f) # sanity check
table(dat.collapse$riskXfemale, dat.collapse$female.f) # sanity check
table(dat.collapse$riskXfemale, dat.collapse$risk.f) # sanity check

dat.collapse$SessionID.f <- as.factor(dat.collapse$SessionID.f)
table(dat.collapse$SessionID.f) # sanity check
table(dat.collapse$risk.f) # sanity check
dat.collapse$riskgeneralXrisk <- (as.numeric(dat.collapse$risk.f)-1)*dat.collapse$riskgeneral.n
table(dat.collapse$riskgeneralXrisk, dat.collapse$risk.f) # sanity check
table(dat.collapse$riskgeneralXrisk, dat.collapse$riskgeneral.n) # sanity check

# create subject-group dummies
dat$Period.set <- NA
dat$Period.set[dat$Period>=1 & dat$Period<=10] <- 1
dat$Period.set[dat$Period>=11 & dat$Period<=20] <- 2
dat$Period.set[dat$Period>=21 & dat$Period<=30] <- 3
dat$SesSubSet <- as.numeric(dat$SessionID)*1000 + as.numeric(dat$Period.set)*100 + as.numeric(dat$Subject)
length(unique(dat$SesSubSet))

# show session IDs and treatments
table(dat.collapse$SessionID.f, dat.collapse$risk.f)

################################################
################################################
# preregistered analysis and basic statistics
################################################
################################################

# general DV summary
summary(dat.collapse$taken)

# summary statistics, average choices
summaryBy(taken ~ female, data=dat.collapse)
summaryBy(taken ~ risk.f, data=dat.collapse)

# behavior at the end of the experiment
dat.end <- subset(dat, subset = Period >=25)
dat.collapse.end <- summaryBy(taken + risk.f ~ SesSub, data=dat.end, keep.names=T)
summaryBy(taken ~ risk.f, data=dat.collapse.end)

# boxplot of average behavior by gender and treatment
pdf(file="taken-summary.pdf", width=5, height=7)
par(mar=c(10,4,4,2))
boxplot(dat.collapse$taken ~ dat.collapse$risk.f + dat.collapse$female.f, las=2, xaxt="n",
        ylab="average # of tokens taken")
axis(1, at=c(1,2,3,4), labels=c("no punishment, male", "punishment, male", "no punishment, female", "punishment, female"), las=2)
dev.off()

# boxplot of all choices by gender and treatment
par(mar=c(10,4,4,2))
boxplot(dat$taken ~ dat$risk.f + dat$female.f, las=2, xaxt="n")
axis(1, at=c(1,2,3,4), labels=c("no punishment, male", "punishment, male", "no punishment, female", "punishment, female"), las=2)
dev.off()

# basic descriptives: do females take less?
summary( lm(taken ~ female.f, data=dat.collapse) )

# basic descriptives: do those in the punishment treatment take less?
summary( lm(taken ~ risk.f, data=dat.collapse) )


########
# analysis of averaged data (preregistered)
########
avg.mod <- lm(taken ~ female.f + risk.f + riskXfemale, data=dat.collapse)
summary(avg.mod)

# total (FWER-controlling) ME of risk treatment
linearHypothesis(avg.mod, c("riskXfemale", "risk.fpunishment"))

# total (FWER-controlling) ME of gender female
linearHypothesis(avg.mod, c("riskXfemale", "female.ffemale"))


# interaction analysis
# total effect, punishment treatment

fem.vec <- c(0,1)
tot.eff <- coefficients(avg.mod)[3] + coefficients(avg.mod)[4]*fem.vec
sd.tot.eff <- sqrt(vcov(avg.mod)[3,3] + ((fem.vec)^2)*vcov(avg.mod)[4,4] + 2*fem.vec*vcov(avg.mod)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-treatment-by-gender.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-30, 10),
       xlab = "Gender", ylab = "ME of Punishment Treatment")
axis(1, at=c(1,2), labels=c("male", "female"), las=1)
abline(h=0, lty=3)
dev.off()

# show the total effect
tot.eff

# interaction analysis
# total effect, female
treat.vec <- c(0,1)
tot.eff <- coefficients(avg.mod)[2] + coefficients(avg.mod)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(avg.mod)[2,2] + ((treat.vec)^2)*vcov(avg.mod)[4,4] + 2*treat.vec*vcov(avg.mod)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-gender-by-treatment.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-20, 20),
       xlab = "Treatment", ylab = "ME of Gender (Female)")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# show the total effect
tot.eff


########
# analysis of averaged data with controls (preregistered)
########

avg.mod.full <- lm(taken ~ risk.f + female.f + riskXfemale + riskgeneral.n + cheatindex + leader.n + SessionID.f, data=dat.collapse)
summary(avg.mod.full)

# total (FWER-controlling) ME of risk treatment
linearHypothesis(avg.mod.full, c("riskXfemale", "risk.fpunishment"), singular.ok=TRUE)

# total (FWER-controlling) ME of gender female
linearHypothesis(avg.mod.full, c("riskXfemale", "female.ffemale"), singular.ok=TRUE)

# interaction analysis
# total effect, punishment treatment
fem.vec <- c(0,1)
tot.eff <- coefficients(avg.mod.full)[2] + coefficients(avg.mod.full)[4]*fem.vec
sd.tot.eff <- sqrt(vcov(avg.mod.full)[2,2] + ((fem.vec)^2)*vcov(avg.mod.full)[4,4] + 2*fem.vec*vcov(avg.mod.full)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.full$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-treatment-by-gender-controls.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-40, 20),
       xlab = "Gender", ylab = "ME of Punishment Treatment")
axis(1, at=c(1,2), labels=c("male", "female"), las=1)
abline(h=0, lty=3)
dev.off()

# show the total effect
tot.eff

# interaction analysis
# total effect, female
treat.vec <- c(0,1)
tot.eff <- coefficients(avg.mod.full)[3] + coefficients(avg.mod.full)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(avg.mod.full)[3,3] + ((treat.vec)^2)*vcov(avg.mod.full)[4,4] + 2*treat.vec*vcov(avg.mod.full)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.full$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-gender-by-treatment-controls.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-30, 20),
       xlab = "Treatment", ylab = "ME of Gender (Female)")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# show the total effect
tot.eff


########
# random effects model of panel data (preregistered)
########

re.mod <- lmer(taken ~ risk.f + female.f + riskXfemale + riskgeneral.n + cheatindex + leader.n + Period.f + (1|SessionID.n/SesSub), data=dat)
summary(re.mod)

# total (FWER-controlling) ME of risk treatment
linearHypothesis(re.mod, c("riskXfemale", "risk.fpunishment"), singular.ok=TRUE)

# total (FWER-controlling) ME of gender female
linearHypothesis(re.mod, c("riskXfemale", "female.ffemale"), singular.ok=TRUE)


# interaction analysis
# total effect, punishment treatment
fem.vec <- c(0,1)
tot.eff <- fixef(re.mod)[2] + fixef(re.mod)[4]*fem.vec
sd.tot.eff <- sqrt(vcov(re.mod)[2,2] + ((fem.vec)^2)*vcov(re.mod)[4,4] + 2*fem.vec*vcov(re.mod)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=summary(re.mod)$devcomp$dims["nmp"], level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-treatment-by-gender-randeff.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-40, 10),
       xlab = "Gender", ylab = "ME of Punishment Treatment")
axis(1, at=c(1,2), labels=c("male", "female"), las=1)
abline(h = 0, lty=3)
dev.off()

# show the total effect
tot.eff

# interaction analysis
# total effect, female
treat.vec <- c(0,1)
tot.eff <- fixef(re.mod)[3] + fixef(re.mod)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(re.mod)[3,3] + ((treat.vec)^2)*vcov(re.mod)[4,4] + 2*treat.vec*vcov(re.mod)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=summary(re.mod)$devcomp$dims["nmp"], level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-gender-by-treatment-randeff.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-30, 20),
       xlab = "Treatment", ylab = "ME of Gender (Female)")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# show the total effect
tot.eff

stargazer(avg.mod, avg.mod.full, re.mod, type="text",
          out = "preregistered.tex",
          out.header=F,
          keep=c("risk.f", "female.f", "riskXfemale", "riskgeneral.n", "cheatindex", "leader.n", "Constant"),
          covariate.labels = c("female", "punishment treatment", "punishment X female", "risk aversion", 
                               "corruption aversion", "leader", "intercept"), 
          dep.var.labels.include = F, dep.var.caption="",
          keep.stat = c("n"),
          add.lines=list(c("Averaged DV", "Yes", "Yes", "No"),
                         c("Individual REs", "No", "No", "Yes"),
                         c("Session REs", "No", "No", "Yes"),
                         c("Session FEs", "No", "Yes", "No"),
                         c("Period FEs", "No", "No", "Yes"),
                         c("", "", "", "")),
          model.names=FALSE, float=F
          )



########################################################
########################################################
# non-preregistered analysis and basic statistics
########################################################
########################################################


########################################################
# models of how risk acceptance influences takings
########################################################

# plots of taking behavior by risk acceptance status
dat.collapse.p <- subset(dat.collapse, subset = risk.f=="punishment")
plot(dat.collapse.p$taken ~ dat.collapse.p$riskgeneral.n, xlab = "risk aversion", 
     ylab = "tokens taken")
abline(lm(taken ~ riskgeneral.n, data=dat.collapse.p))

dat.collapse.np <- subset(dat.collapse, subset = risk.f=="no punishment")
plot(dat.collapse.np$taken ~ dat.collapse.np$riskgeneral.n, xlab = "risk aversion", 
     ylab = "tokens taken")
abline(lm(taken ~ riskgeneral.n, data=dat.collapse.np))


####
# interaction between risk acceptance and treatment
####

avg.mod.risk <- lm(taken ~ risk.f + riskgeneral.n + riskgeneralXrisk, data=dat.collapse)
summary(avg.mod.risk)

# total (FWER-controlling) ME of treatment
linearHypothesis(avg.mod.risk, c("riskgeneralXrisk", "risk.fpunishment"))

# total (FWER-controlling) ME of risk acceptance
linearHypothesis(avg.mod.risk, c("riskgeneralXrisk", "riskgeneral.n"))


# interaction analysis
# total effect, risk acceptance
treat.vec <- c(0,1)
tot.eff <- coefficients(avg.mod.risk)[3] + coefficients(avg.mod.risk)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(avg.mod.risk)[3,3] + ((treat.vec)^2)*vcov(avg.mod.risk)[4,4] + 2*treat.vec*vcov(avg.mod.risk)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.risk$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-riskaversion-by-treatment.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-10, 5),
       xlab = "Treatment", ylab = "ME of Risk Aversion")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# interaction analysis
# total effect, treatment
risk.vec <- 2:9
tot.eff <- coefficients(avg.mod.risk)[2] + coefficients(avg.mod.risk)[4]*risk.vec
sd.tot.eff <- sqrt(vcov(avg.mod.risk)[2,2] + ((risk.vec)^2)*vcov(avg.mod.risk)[4,4] + 2*risk.vec*vcov(avg.mod.risk)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.risk$df.residual, level=0.95)
ci.hi <- tot.eff + t.star*sd.tot.eff
ci.lo <- tot.eff - t.star*sd.tot.eff
pdf(file="ME-treatment-by-riskaversion.pdf", width=5, height=5.5)
plot(tot.eff ~ risk.vec, type="l", ylim=c(-40, 10), xlab="risk aversion", ylab="ME of punishment treatment")
lines(ci.hi ~ risk.vec, lty=2)
lines(ci.lo ~ risk.vec, lty=2)
abline(h=0, lty=3)
dev.off()



####
# interaction between risk acceptance and treatment, panel data
####

re.mod.risk <- lmer(taken ~ risk.f + riskgeneral.n + riskgeneralXrisk + Period.f + (1|SessionID.n/SesSub), data=dat)
summary(re.mod.risk)


# total (FWER-controlling) ME of treatment
linearHypothesis(re.mod.risk, c("riskgeneralXrisk", "risk.fpunishment"), singularity.ok=TRUE)

# total (FWER-controlling) ME of risk acceptance
linearHypothesis(re.mod.risk, c("riskgeneralXrisk", "riskgeneral.n"))

# coefficients and SEs identical!
fixef(re.mod.risk)
coef(avg.mod.risk)
vcov(re.mod.risk)[1:4, 1:4]
vcov(avg.mod.risk)[1:4, 1:4]



####
# interaction between risk acceptance and treatment, with controls
####

avg.mod.risk.control <- lm(taken ~ risk.f + riskgeneral.n + riskgeneralXrisk + female.f + cheatindex + leader.n + SessionID.f, data=dat.collapse)
summary(avg.mod.risk.control)

# total (FWER-controlling) ME of treatment
linearHypothesis(avg.mod.risk.control, c("riskgeneralXrisk", "risk.fpunishment"), singular.ok=TRUE)

# total (FWER-controlling) ME of risk acceptance
linearHypothesis(avg.mod.risk.control, c("riskgeneralXrisk", "riskgeneral.n"), singular.ok=TRUE)

# interaction analysis
# total effect, risk acceptance
treat.vec <- c(0,1)
tot.eff <- coefficients(avg.mod.risk.control)[3] + coefficients(avg.mod.risk.control)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(avg.mod.risk.control)[3,3] + ((treat.vec)^2)*vcov(avg.mod.risk.control)[4,4] + 2*treat.vec*vcov(avg.mod.risk.control)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.risk.control$df.residual, level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-riskaversion-by-treatment-controls.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-10, 5),
       xlab = "Treatment", ylab = "ME of Risk Aversion")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# interaction analysis
# total effect, treatment
risk.vec <- 2:9
tot.eff <- coefficients(avg.mod.risk.control)[2] + coefficients(avg.mod.risk.control)[4]*risk.vec
sd.tot.eff <- sqrt(vcov(avg.mod.risk.control)[2,2] + ((risk.vec)^2)*vcov(avg.mod.risk.control)[4,4] + 2*risk.vec*vcov(avg.mod.risk.control)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=avg.mod.risk.control$df.residual, level=0.95)
ci.hi <- tot.eff + t.star*sd.tot.eff
ci.lo <- tot.eff - t.star*sd.tot.eff
pdf(file="ME-treatment-by-riskaversion-controls.pdf", width=5, height=5.5)
plot(tot.eff ~ risk.vec, type="l", ylim=c(-50, 30), xlab="risk aversion", ylab="ME of punishment treatment")
lines(ci.hi ~ risk.vec, lty=2)
lines(ci.lo ~ risk.vec, lty=2)
abline(h=0, lty=3)
dev.off()

####
# interaction between risk acceptance and treatment with controls, panel data
####

re.mod.risk.control <- lmer(taken ~ risk.f + riskgeneral.n + riskgeneralXrisk + female.f + cheatindex + leader.n + Period.f + (1|SessionID.n/SesSub), data=dat)
summary(re.mod.risk.control)

# total (FWER-controlling) ME of treatment
linearHypothesis(re.mod.risk.control, c("riskgeneralXrisk", "risk.fpunishment"), singularity.ok=TRUE)

# total (FWER-controlling) ME of risk acceptance
linearHypothesis(re.mod.risk.control, c("riskgeneralXrisk", "riskgeneral.n"))

# interaction analysis
# total effect, risk acceptance
treat.vec <- c(0,1)
tot.eff <- fixef(re.mod.risk.control)[3] + fixef(re.mod.risk.control)[4]*treat.vec
sd.tot.eff <- sqrt(vcov(re.mod.risk.control)[3,3] + ((treat.vec)^2)*vcov(re.mod.risk.control)[4,4] + 2*treat.vec*vcov(re.mod.risk.control)[3,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=summary(re.mod.risk.control)$devcomp$dims["nmp"], level=0.95)
ci.hi <- t.star*sd.tot.eff
ci.lo <- t.star*sd.tot.eff
pdf(file="ME-riskaversion-by-treatment-re-controls.pdf", width=5, height=5.5)
plotCI(x=tot.eff, uiw=ci.hi, liw=ci.lo, xaxt="n", xlim=c(0.7, 2.3), ylim=c(-10, 5),
       xlab = "Treatment", ylab = "ME of Risk Aversion")
axis(1, at=c(1,2), labels=c("no punishment", "punishment"), las=1)
abline(h=0, lty=3)
dev.off()

# interaction analysis
# total effect, treatment
risk.vec <- 2:9
tot.eff <- fixef(re.mod.risk.control)[2] + fixef(re.mod.risk.control)[4]*risk.vec
sd.tot.eff <- sqrt(vcov(re.mod.risk.control)[2,2] + ((risk.vec)^2)*vcov(re.mod.risk.control)[4,4] + 2*risk.vec*vcov(re.mod.risk.control)[2,4])
t.star <- fdrInteraction(tot.eff, sd.tot.eff, df=summary(re.mod.risk.control)$devcomp$dims["nmp"], level=0.95)
ci.hi <- tot.eff + t.star*sd.tot.eff
ci.lo <- tot.eff - t.star*sd.tot.eff
pdf(file="ME-treatment-by-riskaversion-re-controls.pdf", width=5, height=5.5)
plot(tot.eff ~ risk.vec, type="l", ylim=c(-50, 30), xlab="risk aversion", ylab="ME of punishment treatment")
lines(ci.hi ~ risk.vec, lty=2)
lines(ci.lo ~ risk.vec, lty=2)
abline(h=0, lty=3)
dev.off()

stargazer(avg.mod.risk, avg.mod.risk.control, type="text",
          out = "risk-analysis.tex",
          out.header=F,
          keep=c("risk.f", "riskgeneral.n", "riskgeneralXrisk", "female.f", "cheatindex", "leader.n", "Constant"),
          covariate.labels = c("punishment treatment", "risk aversion", "treatment X risk aversion",
                               "female", "corruption aversion", "leader", "intercept"), 
          dep.var.labels.include = F, dep.var.caption="",
          keep.stat = c("n"),
          add.lines=list(c("Session FEs", "No", "Yes", "No", "No"),
                         c("", "", "", "")),
          model.names=FALSE, float=F
)


########################################################
# models of how gender influences risk aversion
########################################################


# plots of risk aversion by gender
pdf(file="riskaversion-summary.pdf", width=5, height=5.5)
boxplot(riskgeneral.n ~ female.f, data=dat.collapse, ylab = "risk aversion")
dev.off()

dat.collapse$riskgeneral.j <- dat.collapse$riskgeneral.n + runif(length(dat.collapse$riskgeneral.n), -0.5, 0.5)
plot(riskgeneral.j ~ female, data=dat.collapse, xlim = c(-0.2, 1.2))
abline(lm(riskgeneral.n ~ female, data=dat.collapse))

# model with no controls
avg.mod.riskdv <- lm(riskgeneral.n ~ female.f, data=dat.collapse)
summary(avg.mod.riskdv)

# model with controls
avg.mod.riskdv.control <- lm(riskgeneral.n ~ female.f + SessionID.f, data=dat.collapse)
summary(avg.mod.riskdv.control)

stargazer(avg.mod.riskdv, avg.mod.riskdv.control, type="text",
          out = "risk-aversion-analysis.tex",
          out.header=F,
          keep=c("female.f", "Constant"),
          covariate.labels = c("female", "intercept"), 
          dep.var.labels.include = F, dep.var.caption="",
          keep.stat = c("n"),
          add.lines=list(c("Session FEs", "No", "Yes"),
                         c("", "", "", "")),
          model.names=FALSE, float=F
)



########################################################
# models of how corruption aversion influences takings
########################################################

avg.mod.cheat <- lm(taken ~ cheatbenefit.n, data=dat.collapse)
summary(avg.mod.cheat)

avg.mod.cheat.2 <- lm(taken ~ cheattax.n, data=dat.collapse)
summary(avg.mod.cheat.2)

avg.mod.cheat.3 <- lm(taken ~ cheattrans.n, data=dat.collapse)
summary(avg.mod.cheat.3)

avg.mod.cheat.4 <- lm(taken ~ cheatbribe.n, data=dat.collapse)
summary(avg.mod.cheat.4)

avg.mod.cheat.5 <- lm(taken ~ cheatindex, data=dat.collapse)
summary(avg.mod.cheat.5)

stargazer(avg.mod.cheat, avg.mod.cheat.2, avg.mod.cheat.3, avg.mod.cheat.4, avg.mod.cheat.5, type="text",
          out = "corruption-tolerance.tex",
          out.header=F,
          covariate.labels = c("claim benefits", "cheat taxes", "avoid fare", "accept bribe", "corruption index", "intercept"), 
          dep.var.labels.include = F, dep.var.caption="",
          keep.stat = c("n"),
          model.names=FALSE, float=F
)


########################################################
# models of how gender influences corruption aversion 
########################################################

boxplot(cheatbenefit.n ~ female.f, data=dat.collapse, 
        ylab = "justifiable: falsely claiming benefits",
        xlab = "gender")
avg.mod.cheat.gender <- lm(cheatbenefit.n ~ female.f, data=dat.collapse)
summary(avg.mod.cheat.gender)

boxplot(cheattax.n ~ female.f, data=dat.collapse, 
        ylab = "justifiable: cheating on taxes",
        xlab = "gender")
avg.mod.cheat.gender.2 <- lm(cheattax.n ~ female.f, data=dat.collapse)
summary(avg.mod.cheat.gender.2)

boxplot(cheattrans.n ~ female.f, data=dat.collapse, 
        ylab = "justifiable: avoiding pub. transport fare",
        xlab = "gender")
avg.mod.cheat.gender.3 <- lm(cheattrans.n ~ female.f, data=dat.collapse)
summary(avg.mod.cheat.gender.3)

boxplot(cheatbribe.n ~ female.f, data=dat.collapse, 
        ylab = "justifiable: accepting a bribe",
        xlab = "gender")
avg.mod.cheat.gender.4 <- lm(cheatbribe.n ~ female.f, data=dat.collapse)
summary(avg.mod.cheat.gender.4)

pdf(file="tolerance-summary.pdf", width=5, height=5.5)
boxplot(cheatindex ~ female.f, data=dat.collapse, 
        ylab = "sum of corruption justifiability ratings",
        xlab = "gender")
dev.off()
avg.mod.cheat.gender.5 <- lm(cheatindex ~ female.f, data=dat.collapse)
summary(avg.mod.cheat.gender.5)


stargazer(avg.mod.cheat.gender, avg.mod.cheat.gender.2, avg.mod.cheat.gender.3, avg.mod.cheat.gender.4, 
          avg.mod.cheat.gender.5, type="text",
          out = "gender-corruption.tex",
          out.header=F,
          covariate.labels = c("female", "intercept"),
          dep.var.labels = c("benefits", "taxes", "fare", "bribe", "index"), 
          dep.var.labels.include = T, dep.var.caption="",
          keep.stat = c("n"),
          model.names=FALSE, float=F
)


####
# add risk aversion control
####

avg.mod.cheat.gender.6 <- lm(cheatbenefit.n ~ female.f + riskgeneral.n, data=dat.collapse)
summary(avg.mod.cheat.gender.6)

avg.mod.cheat.gender.7 <- lm(cheattax.n ~ female.f + riskgeneral.n, data=dat.collapse)
summary(avg.mod.cheat.gender.7)

avg.mod.cheat.gender.8 <- lm(cheattrans.n ~ female.f + riskgeneral.n, data=dat.collapse)
summary(avg.mod.cheat.gender.8)

avg.mod.cheat.gender.9 <- lm(cheatbribe.n ~ female.f + riskgeneral.n, data=dat.collapse)
summary(avg.mod.cheat.gender.9)

avg.mod.cheat.gender.10 <- lm(cheatindex ~ female.f + riskgeneral.n, data=dat.collapse)
summary(avg.mod.cheat.gender.10)


stargazer(avg.mod.cheat.gender.6, avg.mod.cheat.gender.7, avg.mod.cheat.gender.8, avg.mod.cheat.gender.9, 
          avg.mod.cheat.gender.10, type="text",
          out = "gender-corruption-risk.tex",
          out.header=F,
          covariate.labels = c("female", "risk aversion", "intercept"),
          dep.var.labels = c("benefits", "taxes", "fare", "bribe", "index"), 
          dep.var.labels.include = T, dep.var.caption="",
          keep.stat = c("n"),
          model.names=FALSE, float=F
)



########################################################
# structural equation model 
########################################################

# code syntax and basic idea taken from:
# http://www.rpubs.com/tbihansk/302732 and
# http://lavaan.ugent.be/tutorial/inspect.html

library(lavaan)
library(semPlot)
library(mice)
library(semTools)

# sem with FIML imputation

model <- '
taken ~ risk.f + cc*female + a*riskgeneral.n + b*cheatindex
cheatindex ~ c*riskgeneral.n + bb*female
riskgeneral.n ~ aa*female

total:= a + b*c
direct:= a
indirect:= b*c

total.f:= cc + bb*b + aa*a
direct.f:= cc
indirect.f:= bb*b + aa*a
'

fit <- cfa(model, data=dat.collapse, missing="FIML", se="robust")
summary(fit, fit.measures=T)

pdf(file="path-diagram.pdf", width=6, height=5)
suppressWarnings(
  semPaths(fit, what='std', layout = 'tree2', whatLabels='par', intercepts=FALSE, residuals=FALSE, trans=FALSE, fade=FALSE, 
           nCharNodes=0, sizeMan=10, curvature=2.5, exoVar=FALSE, exoCov=FALSE, thresholds=FALSE,
           edge.label.cex=1.2, edge.width=0.7, edge.label.color="black",
           nodeLabels=c(paste("  tokens", "\n", "taken"),paste("  corruption"," \n", "aversion"), 
                        paste("  risk","\n", "aversion"),"punishment","female")
           )
)
dev.off()


# what you get w/o imputation

fit.lwd <- cfa(model, data=dat.collapse, missing="listwise", se="robust")
summary(fit.lwd, fit.measures=T)



# robustness check: SEM with MICE imputation

set.seed(654321)
dat.collapse.s <- subset(dat.collapse, select = c("taken", "risk.f", "riskgeneral.n", "female", "cheatindex"))
table(dat.collapse.s$risk.f, as.numeric(dat.collapse.s$risk.f)-1)
dat.collapse.s$risk.f <- as.numeric(dat.collapse.s$risk.f)-1
mice.obj <- mice(dat.collapse.s, m=30, method=c("", "", "pmm", "pmm", "pmm"))
dat.collapse.mice <- NULL
for(i in 1:30){dat.collapse.mice[[i]] <- complete(mice.obj, action=i, inc=FALSE)}
fit.mi <- cfa.mi(model, data=dat.collapse.mice, se="robust")

summary(fit.mi)



# sanity check: sem with rescaled DV

dat.collapse$taken.d <- dat.collapse$taken/100

model.t <- '
taken.d ~ risk.f + cc*female + a*riskgeneral.n + b*cheatindex
cheatindex ~ c*riskgeneral.n + bb*female
riskgeneral.n ~ aa*female

total:= a + b*c
direct:= a
indirect:= b*c

total.f:= cc + bb*b + aa*a
direct.f:= cc
indirect.f:= bb*b + aa*a
'

fit.t <- cfa(model.t, data=dat.collapse, missing="FIML", se="robust")

summary(fit.t)
varTable(fit.t)

suppressWarnings(
  semPaths(fit.t, what='std', layout = 'tree2', whatLabels='par', intercepts=FALSE, residuals=FALSE, trans=FALSE, fade=FALSE, 
           nCharNodes=0, sizeMan=10, curvature=2.5, exoVar=FALSE, exoCov=FALSE, thresholds=FALSE,
           edge.label.cex=1.2, edge.width=0.7, edge.label.color="black",
           nodeLabels=c(paste("  tokens", "\n", "taken"),paste("  corruption"," \n", "aversion"), 
                        paste("  risk","\n", "aversion"),"punishment","female")
  )
)


# include leadership as a (binary) variable

model.l <- '
taken ~ a*risk.f + b*riskgeneral.n + c*female + d*cheatindex + e*leader.n
cheatindex ~ f*riskgeneral.n + g*female
riskgeneral.n ~ h*female
leader.n ~ i*cheatindex + j*female + k*riskgeneral.n

total:= b + d*f + e*k
direct:= b
indirect:= d*f + e*k

total.f:= c + d*g + b*h + e*j
direct.f:= c
indirect.f:= d*g + b*h + e*j

total.c:= d + i*e
direct.c:= d
indirect.c:= i*e

'

fit.l <- cfa(model.l, data=dat.collapse, estimator="WLSMV", missing="pairwise",  se="robust", ordered="leader.n",
             test="mean.var.adjusted")
summary(fit.l, fit.measures=T)

pdf(file="path-diagram-l.pdf", width=6, height=5)
suppressWarnings(
  semPaths(fit.l, what='std', layout = 'tree2', whatLabels='par', intercepts=FALSE, residuals=FALSE, trans=FALSE, fade=FALSE, 
           nCharNodes=0, sizeMan=10, curvature=2.5, exoVar=FALSE, exoCov=FALSE, thresholds=FALSE,
           edge.label.cex=1.2, edge.width=0.7, edge.label.color="black",
           nodeLabels=c(paste("  tokens", "\n", "taken"),paste("  corruption"," \n", "aversion"), 
                        paste("  risk","\n", "aversion"), "leader","punishment","female")
  )
)
dev.off()


# make a nice table of results
# code from https://rpubs.com/mkearney/103040
# and https://groups.google.com/forum/#!topic/lavaan/ZEdEAPL3V5Y
pars.regressions <- parameterEstimates(fit.l)[ parameterEstimates(fit.l)[,'op']=="~",c(1,3,5,6,8)]
pars.regressions[,1] <- c(rep("tokens taken", 5), rep("corruption aversion", 2), "risk aversion", rep("leader", 3))
pars.regressions[,2] <- c("punishment", "risk aversion", "female", "corruption aversion", "leader", 
                          "risk aversion", "female", "female", "corruption aversion", "female", "risk aversion")
fit.measures <- fitMeasures(fit.l)[c("chisq", "df", "pvalue", "chisq.scaled", "df.scaled", 
                                     "pvalue.scaled", "rmsea.scaled", "rmsea.pvalue.scaled")]
names(fit.measures) = c("$\\chi^2$ fit statistic", "df", "$p$-value",
                        "$\\chi^2$ fit-statistic", "df", "$p$-value",
                        "RMSEA", "RMSEA 5\\% $p$-value")
notes.txt <- c( paste(names(fit.measures)[4:6], " = ", round(fit.measures[4:6],3), collapse=", "),
                paste(names(fit.measures)[7:8], " = ", round(fit.measures[7:8],3), collapse=", ")
              )

stargazer(pars.regressions, summary=F, type="text", rownames=F, digits=3,
          out = "experiment-sem-model.tex", out.header=F, float=F,
          covariate.labels=c("dependent var.", "independent var.", "coef.", "se", "$p$-value"),
          notes=notes.txt, notes.align="c"
)


# what you get w/o imputation

fit.l.lwd <- cfa(model.l, data=dat.collapse, estimator="WLSMV", missing="listwise",  se="robust", ordered="leader.n",
                 test="mean.var.adjusted")
summary(fit.l.lwd, fit.measures=T)

write.dta(dat.collapse, file="collapsed-appropriation-data.dta")
